@@ -12,6 +12,7 @@
 #include "daemoninterface.h"
 #include "deviceinterface.h"
 #include "batteryinterface.h"
+#include "connectivityinterface.h"
 #include "devicesftpinterface.h"
 #include "devicefindmyphoneinterface.h"
 #include "devicenotificationsinterface.h"
@@ -88,7 +89,21 @@ public:
     ~BatteryDbusInterface() override;
 
 Q_SIGNALS:
-    void refreshedProxy();
+    void refreshedProxy(bool isCharging, int charge);
+};
+
+class KDECONNECTINTERFACES_EXPORT ConnectivityReportDbusInterface
+    : public OrgKdeKdeconnectDeviceConnectivity_reportInterface
+{
+    Q_OBJECT
+    Q_PROPERTY(QString cellularNetworkType READ cellularNetworkType NOTIFY refreshedProxy)
+    Q_PROPERTY(int cellularNetworkStrength READ cellularNetworkStrength NOTIFY refreshedProxy)
+public:
+    explicit ConnectivityReportDbusInterface(const QString& deviceId, QObject* parent = nullptr);
+    ~ConnectivityReportDbusInterface() override;
+
+Q_SIGNALS:
+    void refreshedProxy(QString cellularNetworkType, int cellularNetworkStrength);
 };
 
 class KDECONNECTINTERFACES_EXPORT DeviceNotificationsDbusInterface
